.. _loss_functions:

Loss functions
==============

.. autoclass:: mumott.optimization.loss_functions.SquaredLoss
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.loss_functions.HuberLoss
   :members:
   :inherited-members:

